@@ -11,7 +11,7 @@ use overload
     '""' => \&as_string,
     fallback => 1;
 
-$VERSION = '0.85';
+$VERSION = '0.9';
 
 1;
 
@@ -156,7 +156,7 @@ use vars qw($VERSION);
 
 use fields qw( package filename line subroutine hasargs wantarray evaltext is_require hints bitmask args );
 
-$VERSION = '0.5';
+$VERSION = '0.6';
 
 # Create accessor routines
 BEGIN
@@ -240,12 +240,9 @@ sub as_string
 	    {
 		# set args to the string "undef" if undefined
 		$_ = "undef", next unless defined $_;
-		if (ref $_)
-		{
-		    # dunno what this is for... (I bet it's to force a
-		    # stringification if available -dave)
-		    $_ .= '';
-		}
+
+		# force stringification
+		$_ .= '' if ref $_;
 
 		s/'/\\'/g;
 
@@ -301,8 +298,8 @@ well as providing a simple interface to this data.
 
 The Devel::StackTrace object contains a set of Devel::StackTraceFrame
 objects, one for each level of the stack.  The frames contain all the
-data available from caller() as of Perl 5.00503.  There are changes in
-Perl 5.6.0 that have yet to be incorporated.
+data available from caller() as of Perl 5.6.0 though this module still
+works with 5.00503.
 
 This code was created to support my L<Exception::Class::Base> class
 (part of Exception::Class) but may be useful in other contexts.
@@ -427,7 +424,7 @@ Returns undef if the frame was not part of a require.
 Returns the arguments passed to the frame.  Note that any arguments
 that are references are returned as references, not copies.
 
-=head2 Perl 5.6.0 and greater _ONLY_
+=head2 These only contain data as of Perl 5.6.0 or later
 
 =item * hints
 
